@@ -4,22 +4,28 @@
 # Synopsis: 	Used by gatherHeaderDoc.pl to hold references to doc 
 #		for individual headers and classes
 # Author: Matt Morse (matt@apple.com)
-# Last Updated: $Date: 2003/01/31 23:54:39 $
+# Last Updated: $Date: 2004/06/02 22:39:14 $
 # 
-# Copyright (c) 1999 Apple Computer, Inc.  All Rights Reserved.
-# The contents of this file constitute Original Code as defined in and are
-# subject to the Apple Public Source License Version 1.1 (the "License").
-# You may not use this file except in compliance with the License.  Please
-# obtain a copy of the License at http://www.apple.com/publicsource and
-# read it before using this file.
+# Copyright (c) 1999-2004 Apple Computer, Inc.  All rights reserved.
 #
-# This Original Code and all software distributed under the License are
-# distributed on an TAS ISU basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+# @APPLE_LICENSE_HEADER_START@
+#
+# This file contains Original Code and/or Modifications of Original Code
+# as defined in and that are subject to the Apple Public Source License
+# Version 2.0 (the 'License'). You may not use this file except in
+# compliance with the License. Please obtain a copy of the License at
+# http://www.opensource.apple.com/apsl/ and read it before using this
+# file.
+# 
+# The Original Code and all software distributed under the License are
+# distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 # EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
-# INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY, FITNESS
-# FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the License for
-# the specific language governing rights and limitations under the
-# License.
+# INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+# Please see the License for the specific language governing rights and
+# limitations under the License.
+#
+# @APPLE_LICENSE_HEADER_END@
 #
 ######################################################################
 package HeaderDoc::DocReference;
@@ -49,6 +55,7 @@ sub new {
 sub _initialize {
     my($self) = shift;
     $self->{OUTPUTFORMAT} = undef;
+    $self->{UID} = undef;
     $self->{NAME} = undef;
     $self->{TYPE} = undef; # Header, CPPClass, etc
     $self->{PATH} = undef;
@@ -85,6 +92,16 @@ sub outputformat {
 }
 
 
+sub uid {
+    my $self = shift;
+
+    if (@_) {
+        $self->{UID} = shift;
+    }
+    return $self->{UID};
+}
+
+
 sub name {
     my $self = shift;
 
@@ -95,6 +112,16 @@ sub name {
 }
 
 
+sub shortname {
+    my $self = shift;
+
+    if (@_) {
+        $self->{SHORTNAME} = shift;
+    }
+    return $self->{SHORTNAME};
+}
+
+
 sub type {
     my $self = shift;
 
@@ -109,6 +136,7 @@ sub printObject {
     my $self = shift;
  
     print "----- DocReference Object ------\n";
+    print "uid:  $self->{UID}\n";
     print "name: $self->{NAME}\n";
     print "type: $self->{TYPE}\n";
     print "path: $self->{PATH}\n";
