@@ -7,22 +7,28 @@
 # Initial modifications: SKoT McDonald <skot@tomandandy.com> Aug 2001
 #
 # Based on CPPClass by Matt Morse (matt@apple.com)
-# Last Updated: $Date: 2003/06/17 23:55:07 $
+# Last Updated: $Date: 2004/06/10 22:12:16 $
 # 
-# Copyright (c) 1999-2001 Apple Computer, Inc.  All Rights Reserved.
-# The contents of this file constitute Original Code as defined in and are
-# subject to the Apple Public Source License Version 1.1 (the "License").
-# You may not use this file except in compliance with the License.  Please
-# obtain a copy of the License at http://www.apple.com/publicsource and
-# read it before using this file.
+# Copyright (c) 1999-2004 Apple Computer, Inc.  All rights reserved.
 #
-# This Original Code and all software distributed under the License are
-# distributed on an TAS ISU basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+# @APPLE_LICENSE_HEADER_START@
+#
+# This file contains Original Code and/or Modifications of Original Code
+# as defined in and that are subject to the Apple Public Source License
+# Version 2.0 (the 'License'). You may not use this file except in
+# compliance with the License. Please obtain a copy of the License at
+# http://www.opensource.apple.com/apsl/ and read it before using this
+# file.
+# 
+# The Original Code and all software distributed under the License are
+# distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 # EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
-# INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY, FITNESS
-# FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the License for
-# the specific language governing rights and limitations under the
-# License.
+# INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+# Please see the License for the specific language governing rights and
+# limitations under the License.
+#
+# @APPLE_LICENSE_HEADER_END@
 #
 ######################################################################
 BEGIN {
@@ -45,7 +51,7 @@ $VERSION = '1.20';
 ################ Portability ###################################
 my $isMacOS;
 my $pathSeparator;
-if ($^O =~ /MacOS/i) {
+if ($^O =~ /MacOS/io) {
 	$pathSeparator = ":";
 	$isMacOS = 1;
 } else {
@@ -57,18 +63,19 @@ my $debugging = 0;
 my $tracing = 0;
 my $outputExtension = ".html";
 my $tocFrameName = "toc.html";
-my $theTime = time();
-my ($sec, $min, $hour, $dom, $moy, $year, @rest);
-($sec, $min, $hour, $dom, $moy, $year, @rest) = localtime($theTime);
-$moy++;
-$year += 1900;
-my $dateStamp = "$moy/$dom/$year";
+# my $theTime = time();
+# my ($sec, $min, $hour, $dom, $moy, $year, @rest);
+# ($sec, $min, $hour, $dom, $moy, $year, @rest) = localtime($theTime);
+# $moy++;
+# $year += 1900;
+# my $dateStamp = "$moy/$dom/$year";
 ######################################################################
 
 sub _initialize {
     my($self) = shift;
     $self->SUPER::_initialize();
     $self->tocTitlePrefix('Protocol:');
+    $self->{CLASS} = "HeaderDoc::ObjCProtocol";
 }
 
 sub getMethodType {
@@ -81,21 +88,19 @@ sub getMethodType {
 sub docNavigatorComment {
     my $self = shift;
     my $name = $self->name();
-    my $navComment = "<!-- headerDoc=intf; name=$name-->";
-    my $appleRef = "<a name=\"//apple_ref/occ/intf/$name\"></a>";
+    $name =~ s/;//sgo;
+    my $uid = $self->apiuid("intf"); # "//apple_ref/occ/intf/$name";
+    my $navComment = "<!-- headerDoc=intf; uid=$uid; name=$name-->";
+    my $appleRef = "<a name=\"$uid\"></a>";
     
     return "$navComment\n$appleRef";
 }
 
 ################## Misc Functions ###################################
 sub objName { # used for sorting
-   my $obj1 = $a;
-   my $obj2 = $b;
-   if ($HeaderDoc::sort_entries) {
-        return ($obj1->name() cmp $obj2->name());
-   } else {
-        return (1 cmp 2);
-   }
+    my $obj1 = $a;
+    my $obj2 = $b;
+    return ($obj1->name() cmp $obj2->name());
 }
 
 1;
